lidarwind.lidarwind\_config.Configurations
==========================================

.. currentmodule:: lidarwind.lidarwind_config

.. autoclass:: Configurations

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~Configurations.__init__
      ~Configurations.generate_conf
      ~Configurations.load_comments
      ~Configurations.load_conf_file
      ~Configurations.load_contact
      ~Configurations.load_email
      ~Configurations.load_institution
      ~Configurations.load_instrument
      ~Configurations.load_reference
      ~Configurations.load_site
      ~Configurations.load_version
   
   

   
   
   